<?php

function get_themes()
{
    $themes = array('light' => _('Light Theme'), 'dark' => _('Dark Theme')); 
    return $themes;
}

function get_user_theme()
{
    $ci =& get_instance();
    $user = $ci->users->get_user();
    return $user['theme'];
}

function get_spacings()
{
    $spacings = array('comfortable' => _('Comfortable'), 'compact' => _('Compact')); 
    return $spacings;
}

function get_user_spacing()
{
    $ci =& get_instance();
    $user = $ci->users->get_user();
    if (empty($user['spacing'])) {
        return 'comfortable';
    }
    return $user['spacing'];
}

function get_user_mode()
{
    $ci =& get_instance();
    $user = $ci->users->get_user();
    return $user['simple_mode'];
}

function get_user_full_name()
{
    $ci =& get_instance();
    $user = $ci->users->get_user();
    return $user['name'];
}